#!/usr/bin/bash
#
# At the time of writing this, JBoss Tools 4.0.0 has been released but
# there isn't any git tags yet, which means there are a couple of extra
# steps to creating the tarball we want. This is also due to the fact
# that upstream has recently moved to Github, and has reorganised the
# entire structure.

GIT_TAG="jbosstools-4.0.0.Final"
MODULES="build build-sites server base jst javaee vpe webservices freemarker"

# Tags will be manually added here to allow reasonable-sized archives.
# Tags based latest commit in branch jbosstools-4.0.x, which are the
# release commits found here (provided by upstream):
# http://download.jboss.org/jbosstools/builds/development/4.0.0.Final.core/2012
# -12-06_13-22-08-B136/logs/ALL_REVISIONS.txt
declare -A commits
commits[base]="83bd0196dcfc2acf25312bf3140fa9222e8daf67"
commits[build]="629e02197dc11023113f36c68cb3f6d2540e610b" #Latest
commits[build-sites]="13cad18f196981a9288a813bb02950a97edb1030" #Latest
commits[freemarker]="6aab590446043db34c7d1522a10898e13e1b0249"
commits[javaee]="524b37a6f1be43e5d59f1bcfe49e3c36fd00f160"
commits[jst]="8ff165f1ae116612d1dc98674e3242f90f39c2d3"
commits[server]="dad906367844c26f7fd77ff55bc97e3056fb5b9a"
commits[vpe]="2809196fcde462a67e451a7e4f96530734eeeeb0"
commits[webservices]="3a785837a5a1afb196422fd66670fbbb96bd6634"

mkdir eclipse-${GIT_TAG}{,-CLEAN}/

pushd eclipse-${GIT_TAG}/
  for module in ${MODULES}; do
    #git clone https://github.com/jbosstools/jbosstools-${module}

    pushd jbosstools-${module}
      git tag ${GIT_TAG} ${commits[${module}]}
      git archive --format=tar --prefix=${module}/ ${GIT_TAG} \
	  | xz > ../../${module}-${GIT_TAG}.tar.xz
    popd
  done
popd

pushd eclipse-${GIT_TAG}-CLEAN
  for module in ${MODULES}; do
    tar xJf ../${module}-${GIT_TAG}.tar.xz
  done

  for ext in jar war zip class; do
    find -type f -name *.${ext} -delete
  done
popd

tar cJf eclipse-${GIT_TAG}-CLEAN.tar.xz eclipse-${GIT_TAG}-CLEAN/
#rm -r eclipse-${GIT_TAG}{,-CLEAN}

for module in ${MODULES}; do
  rm ${module}-${GIT_TAG}.tar.xz
done
